@@ -20,6 +20,22 @@ assert scale_1024
 assert epoch
 
 
+def is_terminal(fd, is_terminal=None):
+    if is_terminal is None:
+        if 'JPY_PARENT_PID' in os.environ:
+            is_terminal = True
+        else:
+            is_terminal = env_flag('PROGRESSBAR_IS_TERMINAL', None)
+
+    if is_terminal is None:  # pragma: no cover
+        try:
+            is_terminal = fd.isatty()
+        except Exception:
+            is_terminal = False
+
+    return is_terminal
+
+
 def deltas_to_seconds(*deltas, **kwargs):  # default=ValueError):
     '''
     Convert timedeltas and seconds as int to seconds as float while coalescing
@@ -122,17 +138,20 @@ class WrappingIO:
         self.target = target
         self.capturing = capturing
         self.listeners = listeners
+        self.needs_clear = False
 
     def write(self, value):
         if self.capturing:
             self.buffer.write(value)
             if '\n' in value:
+                self.needs_clear = True
                 for listener in self.listeners:  # pragma: no branch
                     listener.update()
         else:
             self.target.write(value)
 
     def flush(self):
+        self.needs_clear = False
         self.buffer.flush()
 
     def _flush(self):
@@ -249,6 +268,11 @@ class StreamWrapper(object):
             sys.stderr = self.original_stderr
             self.wrapped_stderr = 0
 
+    def needs_clear(self):  # pragma: no cover
+        stdout_needs_clear = getattr(self.stdout, 'needs_clear', False)
+        stderr_needs_clear = getattr(self.stderr, 'needs_clear', False)
+        return stderr_needs_clear or stdout_needs_clear
+
     def flush(self):
         if self.wrapped_stdout:  # pragma: no branch
             try:
